PyGeoArrayReader

Struct PyGeoArrayReader 

pub struct PyGeoArrayReader { /* private fields */ }
Python wrapper for a GeoArrow array reader (stream).

This type represents a stream of GeoArrow arrays that can be read incrementally. It implements the Arrow C Stream Interface, allowing zero-copy data exchange with Arrow-compatible Python libraries.

The reader can be iterated over to yield individual PyGeoArray chunks, or materialized into a PyGeoChunkedArray using the into_chunked_array() method. For stream processing, prefer into_reader().

Implementations

Source

impl PyGeoArrayReader

pub fn new(reader: Box<dyn GeoArrowArrayReader + Send>) -> Self

Create a new PyGeoArrayReader from a GeoArrow array reader.

pub fn from_arrow_pycapsule( capsule: &Bound<'_, PyCapsule>, ) -> PyGeoArrowResult<Self>

Import from a raw Arrow C Stream capsule

pub fn data_type(&self) -> &GeoArrowType

Get the GeoArrow data type of arrays in this stream.

pub fn into_reader(self) -> PyResult<Box<dyn GeoArrowArrayReader + Send>>

Consume this reader and convert into a ArrayReader.

The reader can only be consumed once. Calling into_reader

pub fn into_chunked_array(self) -> PyGeoArrowResult<PyGeoChunkedArray>

Consume this reader and create a PyGeoChunkedArray object

pub fn to_geoarrow_py<'py>( &'py self, py: Python<'py>, ) -> PyResult<Bound<'py, PyAny>>

Export to a geoarrow.rust.core.GeoArrowArrayReader.

This requires that you depend on geoarrow-rust-core from your Python package.

pub fn into_geoarrow_py(self, py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Export to a geoarrow.rust.core.GeoArrowArrayReader.

This requires that you depend on geoarrow-rust-core from your Python package.