pub struct PyGeoChunkedArray { /* private fields */ }Expand description
Python wrapper for a chunked GeoArrow geometry array.
A chunked array is a collection of contiguous arrays of the same type.
Implementations
Sourceimpl PyGeoChunkedArray
impl PyGeoChunkedArray
Sourcepub fn try_new(
chunks: Vec<Arc<dyn GeoArrowArray>>,
data_type: GeoArrowType,
) -> PyResult<Self>
pub fn try_new( chunks: Vec<Arc<dyn GeoArrowArray>>, data_type: GeoArrowType, ) -> PyResult<Self>
Construct a new PyGeoChunkedArray from existing chunks and a field.
Sourcepub fn from_arrow_pycapsule(
capsule: &Bound<'_, PyCapsule>,
) -> PyGeoArrowResult<Self>
pub fn from_arrow_pycapsule( capsule: &Bound<'_, PyCapsule>, ) -> PyGeoArrowResult<Self>
Import from a raw Arrow C Stream capsule
Sourcepub fn to_geoarrow<'py>(
&'py self,
py: Python<'py>,
) -> PyResult<Bound<'py, PyAny>>
pub fn to_geoarrow<'py>( &'py self, py: Python<'py>, ) -> PyResult<Bound<'py, PyAny>>
Export to a geoarrow.rust.core.GeometryArray.
This requires that you depend on geoarrow-rust-core from your Python package.
Sourcepub fn from_arrays(
chunks: Vec<Arc<dyn GeoArrowArray>>,
) -> PyGeoArrowResult<Self>
pub fn from_arrays( chunks: Vec<Arc<dyn GeoArrowArray>>, ) -> PyGeoArrowResult<Self>
Create a new PyChunkedArray from a vec of ArrayRefs, inferring their data type automatically.
Sourcepub fn into_inner(self) -> (Vec<Arc<dyn GeoArrowArray>>, GeoArrowType)
pub fn into_inner(self) -> (Vec<Arc<dyn GeoArrowArray>>, GeoArrowType)
Consume this wrapper and return the underlying chunks and data type.