pub enum AnyGeoArray {
Array(PyGeoArray),
Stream(PyGeoArrayReader),
}Expand description
An enum over PyGeoArray and PyGeoArrayReader, used when a function accepts either
Arrow object as input.
This type automatically extracts from Python objects that implement either:
__arrow_c_array__(for single arrays)__arrow_c_stream__(for array streams)
Variants
Array(PyGeoArray)
A single Array, held in a PyGeoArray.
Stream(PyGeoArrayReader)
A stream of possibly multiple Arrays, held in a PyGeoArrayReader.
Implementations
Sourceimpl AnyGeoArray
impl AnyGeoArray
Sourcepub fn into_chunked_array(self) -> PyGeoArrowResult<PyGeoChunkedArray>
pub fn into_chunked_array(self) -> PyGeoArrowResult<PyGeoChunkedArray>
Consume this and convert it into a PyGeoChunkedArray.
All arrays from the stream will be materialized in memory.
Sourcepub fn into_reader(self) -> PyResult<Box<dyn GeoArrowArrayReader + Send>>
pub fn into_reader(self) -> PyResult<Box<dyn GeoArrowArrayReader + Send>>
Convert this into a GeoArrow array reader.
Sourcepub fn data_type(&self) -> GeoArrowType
pub fn data_type(&self) -> GeoArrowType
Get the GeoArrow data type of this array or stream.